window { 
 display: block;
 background-color: white; 

} 

iframe {
  height: 125px;
  border: 0px;
}

tree { 
 display: table; 
 background-color: #FFFFFF; 
 border: none; 
 border-spacing: 0px; 
 width: 100%;
} 

treeitem { 
 display: table-row; 
} 

treehead { 
 display: table-header-group; 
} 

treebody { 
 display: table-row-group; 
} 

treecol {
 display: table-column;
 width: 200px;
}

treecell { 
 display: table-cell;
 font-family: Verdana, Sans-Serif;
 font-size: 8pt;
 white-space: nowrap;
} 

treeitem[selected] {
 background-color: #000080;
 color: white;
}
 
treecell[sortActive="true"][sortDirection="ascending"] {
 background-color: green;
 }
 
treecell[sortActive="true"][sortDirection="descending"] {
 background-color: red;
 }
 
treecol[sortActive="true"] {
  background-color: lightgreen;
}

treehead treeitem treecell { 
 background-color: #c0c0c0; 
 border: outset 1px;
 border-color: white #707070 #707070 white;
 vertical-align: middle;
}

treeitem[container="true"][open="true"][loading="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/loading.gif") ! important ;
}

treeitem[type="http://home.netscape.com/NC-rdf#FileSystemObject"][container="true"][open="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/folder-open.gif");
}

treeitem[type="http://home.netscape.com/NC-rdf#FileSystemObject"][container="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/folder-closed.gif");
}

treeitem[type="http://home.netscape.com/NC-rdf#FileSystemObject"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/article.gif");
}

treeitem[container="true"][open="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/folder-open.gif");
}

treeitem[container="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/folder-closed.gif");
}

treeitem > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/document.gif");
}

/*
 *  Sidebar and Panel title buttons
 */
box#sidebox {
  width: 100%;
  height: 100%;
  display:block;
}

box.sidebartitle {
  background-color: #505888;
  font: 10pt sans-serif;
}

box.panelbar {
  background-color: #006870;
  font: 10pt sans-serif;
}

div.sidebartitlelabel {
  color: white;
  padding: 5px;
}

titledbutton[class~=paneltitle] { 
  color: white;
}

