box#outer-box {
  width: 100%;
  height: 100%;
}

select.combobox {
  font-family: Sans-Serif;
  font-size: 8pt;
  border-top: 3px;
  border-left: 4px;
  border-right: 4px;
  border-style: outset;
  //background: silver;
}

titledbutton#TextColorPopup {
  margin-right: -3px;
}

titledbutton#BackColorPopup {
  margin-left: -3px;
}
