/* Address Book specific style */


/* CardEdit styles - used in the Card Edit Dialog */

box[class="CardEdit"] {
	margin: 5px;
	padding: 5px;
	border: 2px groove white;
}

input[class="CardEdit"] {
	height       : 22px;
	width        : 190px;
	margin-left  : 0px;
	margin-right : 0px;
	margin-top   : 1px;
	margin-bottom: 1px;
}


/* CardView styles - used in the Card View Pane*/

div[class="CardViewHeading"] {
	padding: 1px;
	padding-left: 5px;
	color: white;
	background-color: #5050ff;
	font-weight: bold;
	display: none;
}

div[class="CardViewText"] {
	padding-left: 20px;
	padding-right: 2px;
	display: none;
}

box[class="CardView"] {
	padding: 0px;
	padding-top: 12px;
	padding-bottom: 4px;
	border: none;
	display: block;
}

spring[class="CardViewHeadingSpace"] {
	height: 3px;
}


/* General styles */

spring[class="PromptEditSpacing"] {
	width: 5px;
}

/* Standard Tree */

/*
tree {
 display: table;
 background-color: white;
 border: none;
 border-spacing: 0px;
 width: 100%;
 table-layout: fixed;
}

treeitem { 
 display: table-row; 
 color: black;
 font-family: Verdona;
 font-size: 10pt;
} 

treehead { 
 display: table-header-group; 
} 

treebody { 
 display: table-row-group; 
} 

treeitem[selected="true"] { 
 color: white;
 background-color: #666699; 
}

treecell { 
 display: table-cell; 
 white-space: nowrap;
} 

treehead treeitem treecell { 
 font-size: 10pt;
 background-color: #a0a0a0; 
 border: thin black solid; 
 border-top: none;
 color: black;
} 


treecol {
 display: table-column;
}
*/

/* Custom Trees */

tree[class="abDirectory"] treeitem > treecell > titledbutton {
 vertical-align: bottom;
 min-height: 1px;
 min-width: 1px;
 height: 1em;
 width: 1em;
 margin:0px;
 padding:0px;
 list-style-image: url("chrome://addressbook/skin/myaddrbk.gif");
}

tree[class="abResults"] treeitem > treecell > titledbutton {
 vertical-align: middle;
 min-height: 1px;
 min-width: 1px;
 height: 1em;
 width: 2em;
 margin:0px;
 padding:0px;
 list-style-image: url("chrome://addressbook/skin/person.gif");
}

