window { 
 display: block; 
 background-color: #FFFFFF; 
} 

menubar { 
 display: none; 
} 

tree { 
 display: table; 
 background-color: #FFFFFF; 
 border: none; 
 border-spacing: 0px; 
 width: 100%;
}

treecol {
 display: table-column;
 width: 200px;
}

treeitem { 
 display: table-row; 
} 

treehead { 
 display: table-header-group; 
} 

treebody { 
 display: table-row-group; 
} 

treecell { 
 display: table-cell; 
 font-family: Verdana, Sans-Serif;
 font-size: 8pt;
} 

treecell[selectedcell] {
 background-color: yellow;
 }
 
treecell[sortActive="true"][sortDirection="ascending"] {
 background-color: green;
 }
 
treecell[sortActive="true"][sortDirection="descending"] {
 background-color: red;
 }
 
treecol[sortActive="true"] {
  background-color: lightgreen;
}

treehead treeitem treecell { 
 background-color: #c0c0c0; 
 border: outset 1px;
 border-color: white #707070 #707070 white;
 padding-left: 4px;
}

treecell[selectedcell] {
 background-color: yellow;
}

treeitem[container="true"][open="true"][loading="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/loading.gif") ! important ;
}

treeitem[type="http://home.netscape.com/NC-rdf#Folder"] > treecell > titledbutton {
 list-style-image: url("resource:/res/samples/bookmark-folder-closed.gif");
}

treeitem[type="http://home.netscape.com/NC-rdf#Folder"][open="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/samples/bookmark-folder-open.gif");
}

treeitem[type="http://home.netscape.com/NC-rdf#Folder"][id="NC:PersonalToolbarFolder"] > treecell > titledbutton {
 list-style-image: url("resource:/res/samples/personal-folder-closed.gif");
}

treeitem[type="http://home.netscape.com/NC-rdf#Folder"][id="NC:PersonalToolbarFolder"][open="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/samples/personal-folder-open.gif");
}

treeitem[type="http://home.netscape.com/NC-rdf#BookmarkSeparator"] > treecell > titledbutton {
 list-style-image: url("resource:/res/samples/bookmark-item.gif");
}

treeitem[type="http://home.netscape.com/NC-rdf#IEFavorite"] > treecell > titledbutton {
 list-style-image: url("resource:/res/samples/IEFavorite.gif");
}

treeitem[type="http://home.netscape.com/NC-rdf#Bookmark"] > treecell > titledbutton {
 list-style-image: url("resource:/res/samples/bookmark-item.gif");
}

treeitem[type="http://home.netscape.com/NC-rdf#FileSystemObject"][container="true"][open="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/folder-open.gif");
}

treeitem[type="http://home.netscape.com/NC-rdf#FileSystemObject"][container="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/folder-closed.gif");
}

treeitem[type="http://home.netscape.com/NC-rdf#FileSystemObject"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/article.gif");
}

treeitem[container="true"][open="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/folder-open.gif");
}

treeitem[container="true"] > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/folder-closed.gif");
}

treeitem > treecell > titledbutton {
 list-style-image: url("resource:/res/rdf/document.gif");
}

titledbutton#bookmarks {
	list-style-image:url("resource:/res/samples/bookmark-item.gif");
}
